pub struct MockEventsApi {
EventsApi_expectations: MockEventsApi_EventsApi,
}Fields
EventsApi_expectations: MockEventsApi_EventsApiImplementations
Sourceimpl MockEventsApi
impl MockEventsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockEventsApi
impl MockEventsApi
Sourcepub fn expect_get_cipher(&mut self) -> &mut Expectation
pub fn expect_get_cipher(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_cipher method
Sourcepub fn expect_get_organization(&mut self) -> &mut Expectation
pub fn expect_get_organization(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_organization method
Sourcepub fn expect_get_organization_user(&mut self) -> &mut Expectation
pub fn expect_get_organization_user(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_organization_user method
Sourcepub fn expect_get_projects(&mut self) -> &mut Expectation
pub fn expect_get_projects(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_projects method
Sourcepub fn expect_get_provider(&mut self) -> &mut Expectation
pub fn expect_get_provider(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_provider method
Sourcepub fn expect_get_provider_user(&mut self) -> &mut Expectation
pub fn expect_get_provider_user(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_provider_user method
Sourcepub fn expect_get_secrets(&mut self) -> &mut Expectation
pub fn expect_get_secrets(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_secrets method
Sourcepub fn expect_get_service_accounts(&mut self) -> &mut Expectation
pub fn expect_get_service_accounts(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_service_accounts method
Sourcepub fn expect_get_user(&mut self) -> &mut Expectation
pub fn expect_get_user(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_user method